PCASpy
======

PCASpy provides not only the low level python binding to EPICS Portable Channel Access Server
but also the necessary high level abstraction to ease the server tool programming.

Check out `PCASpy documents <https://pcaspy.readthedocs.io>`_ to get started.

* Home: https://github.com/paulscherrerinstitute/pcaspy/wiki
* Documents: https://pcaspy.readthedocs.io
* Downloads: https://pypi.python.org/pypi/pcaspy
* Source Repo: https://github.com/paulscherrerinstitute/pcaspy
* Issue Tracker: https://github.com/paulscherrerinstitute/pcaspy/issues
